@@ -5,9 +5,6 @@
 #![allow(unused_must_use)]
 #![forbid(unsafe_code)]
 
-#[macro_use]
-extern crate lazy_static;
-extern crate once_cell;
 #[macro_use]
 extern crate rbatis_macro_driver;
 #[macro_use]
@@ -26,7 +23,9 @@ pub use crate::rbatis::AsSqlTag;
 
 pub mod crud;
 pub mod plugin;
+
 pub use plugin::*;
+
 pub mod rbatis;
 pub mod sql;
 #[macro_use]
